# ab_j_distributions package

modules to do Generaldistribution, Gaussiandistribution, Binomialdistribution.

# Files

- ab_j_distributions , It is contine all three modules we mention above as python file's.

# Installation

Run this command:

pip install ab_j_distributions